summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorÉtienne Mollier <emollier@debian.org>2023-06-21 22:25:18 +0200
committerÉtienne Mollier <emollier@debian.org>2023-06-21 22:25:18 +0200
commit97b52b20a0c96bc56fcde7b14a8a3365603eef0f (patch)
tree366b4f2aa44af2cdaa510eb3d7917063a6c81e80
parentace6f1ebd6df32f99e2f6fa741ff33391e8b859d (diff)
fix typos caught by lintian.archive/debian/1.887-1
Forwarded: https://github.com/marioroy/mce-perl/pull/17 Last-Update: 2023-06-21 Last-Update: 2023-06-21 Gbp-Pq: Name typos.patch
-rw-r--r--lib/MCE/Channel/Mutex.pm2
-rw-r--r--lib/MCE/Channel/MutexFast.pm2
-rw-r--r--lib/MCE/Channel/Threads.pm2
-rw-r--r--lib/MCE/Channel/ThreadsFast.pm2
-rw-r--r--lib/MCE/Core/Input/Iterator.pm4
5 files changed, 6 insertions, 6 deletions
diff --git a/lib/MCE/Channel/Mutex.pm b/lib/MCE/Channel/Mutex.pm
index e243ee3..9ab6144 100644
--- a/lib/MCE/Channel/Mutex.pm
+++ b/lib/MCE/Channel/Mutex.pm
@@ -323,7 +323,7 @@ The API is described in L<MCE::Channel>.
my $chnl_a = MCE::Channel->new( impl => 'Mutex' );
# Specify the 'mp' option for safe use by two or more producers
- # sending or recieving on the left side of the channel (i.e.
+ # sending or receiving on the left side of the channel (i.e.
# ->enqueue/->send or ->recv2/->recv2_nb).
my $chnl_b = MCE::Channel->new( impl => 'Mutex', mp => 1 );
diff --git a/lib/MCE/Channel/MutexFast.pm b/lib/MCE/Channel/MutexFast.pm
index 149f178..e1af39b 100644
--- a/lib/MCE/Channel/MutexFast.pm
+++ b/lib/MCE/Channel/MutexFast.pm
@@ -335,7 +335,7 @@ Current module available since MCE 1.877.
my $chnl_a = MCE::Channel->new( impl => 'MutexFast' );
# Specify the 'mp' option for safe use by two or more producers
- # sending or recieving on the left side of the channel (i.e.
+ # sending or receiving on the left side of the channel (i.e.
# ->enqueue/->send or ->recv2/->recv2_nb).
my $chnl_b = MCE::Channel->new( impl => 'MutexFast', mp => 1 );
diff --git a/lib/MCE/Channel/Threads.pm b/lib/MCE/Channel/Threads.pm
index c72f8bc..cb288dd 100644
--- a/lib/MCE/Channel/Threads.pm
+++ b/lib/MCE/Channel/Threads.pm
@@ -339,7 +339,7 @@ The API is described in L<MCE::Channel>.
my $chnl_a = MCE::Channel->new( impl => 'Threads' );
# Specify the 'mp' option for safe use by two or more producers
- # sending or recieving on the left side of the channel (i.e.
+ # sending or receiving on the left side of the channel (i.e.
# ->enqueue/->send or ->recv2/->recv2_nb).
my $chnl_b = MCE::Channel->new( impl => 'Threads', mp => 1 );
diff --git a/lib/MCE/Channel/ThreadsFast.pm b/lib/MCE/Channel/ThreadsFast.pm
index f0b1196..330ca93 100644
--- a/lib/MCE/Channel/ThreadsFast.pm
+++ b/lib/MCE/Channel/ThreadsFast.pm
@@ -353,7 +353,7 @@ Current module available since MCE 1.877.
my $chnl_a = MCE::Channel->new( impl => 'ThreadsFast' );
# Specify the 'mp' option for safe use by two or more producers
- # sending or recieving on the left side of the channel (i.e.
+ # sending or receiving on the left side of the channel (i.e.
# ->enqueue/->send or ->recv2/->recv2_nb).
my $chnl_b = MCE::Channel->new( impl => 'ThreadsFast', mp => 1 );
diff --git a/lib/MCE/Core/Input/Iterator.pm b/lib/MCE/Core/Input/Iterator.pm
index 3a2a746..52aa894 100644
--- a/lib/MCE/Core/Input/Iterator.pm
+++ b/lib/MCE/Core/Input/Iterator.pm
@@ -2,7 +2,7 @@
## ----------------------------------------------------------------------------
## Iterator reader.
##
## This package, used interally by the worker process, provides support for
## user specified iterators assigned to input_data.
##
## There is no public API.
@@ -133,7 +133,7 @@ This document describes MCE::Core::Input::Iterator version 1.887
=head1 DESCRIPTION
-This package, used interally by the worker process, provides support for
+This package, used internally by the worker process, provides support for
user specified iterators assigned to C<input_data>.
There is no public API.
@@ -2,7 +2,7 @@
## Iterator reader.
##
-## This package, used interally by the worker process, provides support for
+## This package, used internally by the worker process, provides support for
## user specified iterators assigned to input_data.
##